@@ -11,6 +11,9 @@ def validate_xml(xmlout, schema):
         logger.warning("Could not validate output as LXML is not installed.")
         return xmlout
     if schema is not None:
+        if schema.startswith("FACTUR-X_"):
+            schema = schema.replace("FACTUR-X_", "Factur-X_1.0.07_")
+            schema = schema.replace("BASIC-WL", "BASICWL")
         schema = etree.XMLSchema(
             file=os.path.join(os.path.dirname(__file__), "schema", schema + ".xsd")
         )
